@@ -3,9 +3,11 @@ Main interface for rds-data service type definitions.
 
 Usage::
 
-    from mypy_boto3.rds_data.type_defs import ArrayValueTypeDef
+    ```python
+    from mypy_boto3_rds_data.type_defs import ArrayValueTypeDef
 
     data: ArrayValueTypeDef = {...}
+    ```
 """
 import sys
 from typing import List
